Distributions of 10 environmental variables for 389 grid cells in Oregon, USA.
data (oregon.env.vars)A data frame with 389 rows and 10 columns.
Row names are hexagon identifiers from White et al. (1992). Variables (columns) are
| bird.spp | number of native breeding bird species |
| x | x coordinate of center of grid cell |
| y | y coordinate of center of grid cell |
| jan.temp | mean minimum January temperature (C) |
| jul.temp | mean maximum July temperature (C) |
| rng.temp | mean difference between July and January temperatures (C) |
| ann.ppt | mean annual precipitation (mm) |
| min.elev | minimum elevation (m) |
| rng.elev | range of elevation (m) |
| max.slope | maximum slope (percent) |
White, D., Preston, E.M., Freemark, K.E., Kiester, A.R. (1999) A hierarchical framework for conserving biodiversity, Landscape ecological analysis: issues and applications, Klopatek, J.M., Gardner, R.H., editors, Springer-Verlag, pp. 127-153.
White, D., Kimerling, A.J., Overton, W.S. (1992) Cartographic and geometric components of a global sampling design for environmental monitoring, Cartography and Geographic Information Systems, 19(1), 5-22.
oregon.bird.dist,
oregon.grid,
oregon.border